@@ -257,7 +257,7 @@ class AppGroup {
     setMargin() {
         let direction = this.state.isHorizontal ? 'right' : 'bottom';
         let existingStyle = this.actor.style ? this.actor.style : '';
-        this.actor.style = existingStyle + 'margin-' + direction + ': ' + this.state.settings.iconSpacing + 'px;';
+        this.actor.style = existingStyle + 'margin-' + direction + ':6px;';
     }
 
     updateIconBoxClip() {
@@ -341,13 +341,12 @@ class AppGroup {
     getPreferredWidth(actor, forHeight, alloc) {
         let [iconMinSize, iconNaturalSize] = this.iconBox.get_preferred_width(forHeight);
         let [labelMinSize, labelNaturalSize] = this.label.get_preferred_width(forHeight);
-        let {iconSpacing} = this.state.settings;
         // The label text starts in the center of the icon, so we should allocate the space
         // needed for the icon plus the space needed for(label - icon/2)
-        alloc.min_size = iconNaturalSize + iconSpacing;
+        alloc.min_size = iconNaturalSize + 6;
         if (this.state.orientation === St.Side.TOP || this.state.orientation === St.Side.BOTTOM) {
             let max = this.labelVisible && this.groupState.metaWindows.length > 0 ?
-                labelNaturalSize + iconNaturalSize + iconSpacing : 0;
+                labelNaturalSize + iconNaturalSize + 6 : 0;
             alloc.natural_size = Math.min(iconNaturalSize + Math.max(max, labelNaturalSize), MAX_BUTTON_WIDTH * global.ui_scale);
         } else {
             alloc.natural_size = this.state.trigger('getPanelHeight');
@@ -366,7 +365,6 @@ class AppGroup {
         let allocHeight = box.y2 - box.y1;
         let childBox = new Clutter.ActorBox();
         let direction = this.actor.get_text_direction();
-        let {iconSpacing} = this.state.settings;
         let spacing = 0;
 
         // Set the icon to be left-justified (or right-justified) and centered vertically
@@ -378,7 +376,7 @@ class AppGroup {
 
         if (this.labelVisible && this.groupState.metaWindows.length > 0) {
             if (direction === Clutter.TextDirection.LTR) {
-                childBox.x1 = box.x1 + iconSpacing;
+                childBox.x1 = box.x1 + 6;
             } else {
                 childBox.x1 = Math.max(box.x1, box.x2 - naturalWidth);
             }
@@ -671,11 +669,6 @@ class AppGroup {
         return this.actor;
     }
 
-    showOrderLabel(number) {
-        this.numberLabel.text = (number + 1).toString();
-        this.badge.show();
-    }
-
     launchNewInstance() {
         this.groupState.app.open_new_window(-1);
         this.animate();
@@ -787,33 +780,6 @@ class AppGroup {
         return false;
     }
 
-    onAppKeyPress() {
-        if (this.groupState.isFavoriteApp && this.groupState.metaWindows.length === 0) {
-            this.launchNewInstance();
-        } else {
-            if (this.appKeyTimeout) {
-                clearTimeout(this.appKeyTimeout);
-                this.appKeyTimeout = 0;
-            }
-            if (this.groupState.metaWindows.length > 1) {
-                if (!this.hoverMenu) this.initThumbnailMenu();
-                this.hoverMenu.open(true);
-            } else {
-                this.listState.trigger('closeAllHoverMenus');
-            }
-            this.windowHandle();
-            this.appKeyTimeout = setTimeout(() => {
-                if (this.groupState.thumbnailMenuEntered) {
-                    clearTimeout(this.appKeyTimeout);
-                    this.appKeyTimeout = 0;
-                    return;
-                }
-                this.hoverMenu.close(true);
-                this.appKeyTimeout = 0;
-            }, this.state.settings.showAppsOrderTimeout);
-        }
-    }
-
     windowHandle() {
         if (this.groupState.lastFocused.appears_focused) {
             if (this.groupState.metaWindows.length > 1) {
@@ -870,7 +836,6 @@ class AppGroup {
             // Set the initial button label as not all windows will get updated via signals initially.
             if (this.state.settings.titleDisplay > 1) {
                 this.onWindowTitleChanged(metaWindow);
-                this.state.trigger('updateThumbnailsStyle');
             }
             if (refWindow === -1) {
                 metaWindows.push(metaWindow);
@@ -1011,8 +976,6 @@ class AppGroup {
                 && this.groupState.appId.indexOf(global.display.focus_window.wm_class.toLowerCase()) === -1) {
                 this.hideLabel();
             }
-            // Re-orient the menu after the focus button expands
-            if (this.hoverMenu) this.hoverMenu.setStyleOptions(false);
         }
     }
 
@@ -1060,7 +1023,7 @@ class AppGroup {
         });
     }
 
-    animate(step = 0) {
+    animate() {
         let effect = this.state.settings.launcherAnimationEffect;
 
         if (effect === 1) return;
@@ -1068,24 +1031,22 @@ class AppGroup {
             this.iconBox.set_z_rotation_from_gravity(0.0, Clutter.Gravity.CENTER);
             Tweener.addTween(this.iconBox, {
                 opacity: 70,
-                time: 1.0,
+                time: 0.2,
                 transition: 'linear',
                 onCompleteScope: this,
                 onComplete() {
                     Tweener.addTween(this.iconBox, {
                         opacity: 255,
-                        time: 0.5,
+                        time: 0.2,
                         transition: 'linear'
                     });
                 }
             });
         } else if (effect === 3) {
-            if (step >= 3) return;
-
             this.iconBox.set_pivot_point(0.5, 0.5);
             Tweener.addTween(this.iconBox, {
-                scale_x: 0.7,
-                scale_y: 0.7,
+                scale_x: 0.8,
+                scale_y: 0.8,
                 time: 0.2,
                 transition: 'easeOutQuad',
                 onComplete: () => {
@@ -1093,10 +1054,7 @@ class AppGroup {
                         scale_x: 1.0,
                         scale_y: 1.0,
                         time: 0.2,
-                        transition: 'easeOutQuad',
-                        onComplete: () => {
-                            this.animate(step + 1);
-                        }
+                        transition: 'easeOutQuad'
                     });
                 }
             });
